@@ -1,7 +1,7 @@
 /*******************************************************************************
  ngx_http_h264_streaming_module.c - An Nginx module for streaming Quicktime/MPEG4 files.
 
- Copyright (C) 2008-2023 CodeShop B.V.
+ Copyright (C) 2008-2024 CodeShop B.V.
 
  For licensing see the LICENSE file
 ******************************************************************************/
@@ -1138,6 +1138,14 @@ ngx_streaming_handler_post(ngx_http_request_t *r, mp4_process_context_t* ctx,
 }
 #endif // BUILDING_SMOOTH_STREAMING
 
+static void ngx_bucket_log_error(void* context, fmp4_result result,
+                                 char const* error)
+{
+  ngx_log_t* log = context;
+  ngx_log_error(NGX_LOG_ERR, log, 0, "bucket_read error: %s %s",
+                fmp4_result_to_string(result), error);
+}
+
 static ngx_int_t
 ngx_streaming_handler_get(ngx_http_request_t *r,
                           mp4_process_context_t* context,
@@ -1612,11 +1620,11 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
           {
             uint8_t const* src = 0;
             size_t size = 0;
-            fmp4_result result = bucket_read(bucket, &src, &size);
+            fmp4_result result = bucket_read(bucket, &src, &size,
+                                             ngx_bucket_log_error, log);
             if(result != FMP4_OK)
             {
-              ngx_log_error(NGX_LOG_ERR, log, 0, "bucket_read failed: %s",
-                            fmp4_result_to_string(result));
+              return NGX_ERROR;
             }
 
             b->pos = ngx_pcalloc(r->pool, size);
